@@ -224,6 +224,7 @@ impl Tree {
                                 _ => continue,
                             };
                             if check(v, resource) {
+                                resource.resource_path().segments = segments;
                                 return Some(v);
                             }
                         }
@@ -255,6 +256,7 @@ impl Tree {
                                 _ => continue,
                             };
                             if check(v, resource) {
+                                resource.resource_path().segments = segments;
                                 return Some(v);
                             }
                         }
@@ -293,6 +295,7 @@ impl Tree {
                                 _ => continue,
                             };
                             if check(v, resource) {
+                                resource.resource_path().segments = segments;
                                 return Some(v);
                             }
                         }
@@ -447,7 +450,7 @@ impl Tree {
                     if let Some(captures) = pattern.captures(seg) {
                         let mut is_match = true;
                         for name in names.iter() {
-                            if let Some(m) = captures.name(&name) {
+                            if let Some(m) = captures.name(name) {
                                 let item = if quoted {
                                     PathItem::Segment(m.as_str().to_string())
                                 } else {
